;*********************************************************
;
;		SOFTWARE SPI FR AVR
;
;	Eigenschaften:
;	
;	- Clock Frequency of SCK:	FCPU/32
;	  Symmetrischer Takt wird generiert (mit kleiner
;	  delay Funktion realisiert), sonst theoretisch
;	  schnellere Frequenz mglich
;	  
;	- Pins von SSCK, SMOSI, SMISO sind einstellbar
;	  
;	- Chip Select wird nicht von Assemblercode gesteuert,
;	  sondern muss vom User vor Aufruf der Funktionen
;	  selbst gesteuert und initialisiert werden !!!
;	  
;*********************************************************

#include <avr/io.h>

; Registerdefinitionen
SSPI_DDR  = DDRD
SSPI_PORT = PORTD
SSPI_PIN  = PIND
SMOSI = PD4
SMISO = PD6
SSCK  = PD7

; Arbeitsregister
workreg = 16

;************************************
;
;	Initialisiert SOFTWARE SPI
;
;************************************
.global sspiInit
.func sspiInit
sspiInit:
		push	workreg
		
		in		workreg,_SFR_IO_ADDR(SSPI_DDR)
		ori		workreg,(1<<SMOSI)|(1<<SSCK)
		andi	workreg,~(1<<SMISO)
		out		_SFR_IO_ADDR(SSPI_DDR),workreg
		
		pop		workreg
		ret
.endfunc


;************************************
;
;	Delay fr sspiWriteByte
;
;************************************
delay_16_cycles:
		nop
		nop
		nop
		nop
		nop
		nop
		nop
		nop
		nop
		ret

;************************************
;
;	Schreibt ein Byte
;
;************************************

.global sspiWriteByte
.func sspiWriteByte
sspiWriteByte:
		push	workreg
		ldi		workreg,8

sspi_write:					
		lsl		24	; MSB ins Carry, LSB wird mit 0 gefllt, in r24 ist das bergebene Byte
		brcc	mosi_low
		sbi		_SFR_IO_ADDR(SSPI_PORT),SMOSI
		rjmp	mosi_done		
mosi_low:
		cbi		_SFR_IO_ADDR(SSPI_PORT),SMOSI
		nop		; damit es gleich lange dauert wie beim Setzen von SMOSI
		nop
mosi_done:
		sbi		_SFR_IO_ADDR(SSPI_PORT),SSCK 	;SCK high
		rcall 	delay_16_cycles					; delay fr SCK = F_CPU/32
												; und damit ein symmetrisches Rechtecksignal entsteht

		cbi		_SFR_IO_ADDR(SSPI_PORT),SSCK	;SCK low
	
		;jetzt MISO einlesen
		sbic	_SFR_IO_ADDR(SSPI_PIN),SMISO
		ori		24,0x01 ; bit 0 in workreg2 auf 1 setzen

		dec		workreg
		brne	sspi_write
		
		pop		workreg
		ret
.endfunc


;************************************
;
;	Liest ein Byte
;
;************************************

.global sspiReadByte
.func sspiReadByte
sspiReadByte:
		ldi		r24,0x00
		rcall	sspiWriteByte
		ret
.endfunc
