/****************************************************************************
*																			*
*			AVR Webserver mit Wiznet Modul WIZ810MJ							*
*																			*
*****************************************************************************
*	MCU:				ATmega128											*
*	Clock Frequency:	16 MHz												*
*	External RAM:		32 kB												*
*																			*
*	Interfaces:																*
*		- USB																*
*		- RS232																*
*		- CAN																*
*		- SD Karte															*
*		- Ethernet															*
*		- Software SPI 														*
*			(Hardware Spi fr SD und CAN verwendet)							*
*****************************************************************************/

/****************************************************************************
*																			*		
*			Include															*
*																			*
*****************************************************************************/
#include <avr/io.h>
#include <util/delay.h>
#include "./Interface/USB.h"
#include "./Interface/rprintf.h"
#include "./Interface/uart.h"
#include "./Interface/SoftwareSpi.h"

/****************************************************************************
*																			*
*			Funktionsprototypen												*
*																			*
*****************************************************************************/
void initExtmem (void) __attribute__ ((naked)) __attribute__ ((section (".init0")));


/****************************************************************************
*																			*
*			Initialisiert XMEM Interface									*
*																			*
*****************************************************************************/
void initExtmem (void)
{
	/* Enable XMEM Interface, No Waitstates */
	MCUCR |= (1 << SRE);
}

/****************************************************************************
*																			*
*			MAIN															*
*																			*
*****************************************************************************/
int main (void)
{	
	DDRG |=(1<<PG3);		// Blaue LED, Pin als Ausgang setzen
	PORTG &= ~(1<<PG3);	// Blaue LED aus
	
	//DDRG |=(1<<PG4);		// Rote LED, Pin als Ausgang setzen
	//PORTG |= (1<<PG4);	// Rote LED ein
	
	usbInit();				// USB initialisieren: auf jeden Fall notwendig falls USB Bootloader verwendet
	uartInit();				// Uart initialisieren: auf jeden Fall notwendig falls Uart Bootloader verwendet
	uartSetBaudRate(115200);	// AVR Studio Baudrate, wichtig falls RS232 Booloader verwendet

	while(1)
	{
		PORTG ^= (1<<PG3);
		_delay_ms(200);
	}
}
